@@ -1,7 +1,10 @@
 #!/usr/bin/env python
-
+"""
+Provides all epoch functions
+"""
 import json
 import requests
+from .urls import EPOCH_INFO_URL, EPOCH_PARAMS_URL 
 
 
 def get_epoch_info(epoch_no=None):
@@ -13,10 +16,10 @@ def get_epoch_info(epoch_no=None):
     :rtype: list
     """
     if epoch_no is None:
-        info = requests.get("https://api.koios.rest/api/v0/epoch_info")
+        info = requests.get(EPOCH_INFO_URL)
         info = json.loads(info.content)
     else:
-        info = requests.get("https://api.koios.rest/api/v0/epoch_info?_epoch_no="+str(epoch_no))
+        info = requests.get(EPOCH_INFO_URL + "?_epoch_no=" + str(epoch_no))
         info = json.loads(info.content)
     return info
 
@@ -31,9 +34,9 @@ def get_epoch_params(epoch_no=None):
     :rtype: list
     """
     if epoch_no is None:
-        info = requests.get("https://api.koios.rest/api/v0/epoch_params")
+        info = requests.get(EPOCH_PARAMS_URL)
         info = json.loads(info.content)
     else:
-        info = requests.get("https://api.koios.rest/api/v0/epoch_params?_epoch_no="+str(epoch_no))
+        info = requests.get(EPOCH_PARAMS_URL + "?_epoch_no=" + str(epoch_no))
         info = json.loads(info.content)
     return info
